@@ -3,7 +3,7 @@
 -- |
 -- Module      : Codec.Archive.Zip
 -- Copyright   : John MacFarlane
--- License     : GPL 2 (see LICENSE)
+-- License     : BSD3
 --
 -- Maintainer  : John MacFarlane < jgm at berkeley dot edu >
 -- Stability   : unstable
@@ -55,6 +55,10 @@ module Codec.Archive.Zip
        ) where
 
 import System.Time ( toUTCTime, addToClockTime, CalendarTime (..), ClockTime (..), TimeDiff (..) )
+#if MIN_VERSION_directory(1,2,0)
+import Data.Time.Clock.POSIX ( utcTimeToPOSIXSeconds )
+#else
+#endif
 import Data.Bits ( shiftL, shiftR, (.&.) )
 import Data.Binary
 import Data.Binary.Get
@@ -199,7 +203,12 @@ readEntry opts path = do
   contents <- if isDir
                  then return B.empty
                  else B.readFile path
+#if MIN_VERSION_directory(1,2,0)
+  modEpochTime <- liftM (floor . utcTimeToPOSIXSeconds)
+                   $ getModificationTime path
+#else
   (TOD modEpochTime _) <- getModificationTime path
+#endif
   let entry = toEntry path' modEpochTime contents
   when (OptVerbose `elem` opts) $ do
     let compmethod = case eCompressionMethod entry of
@@ -578,7 +587,8 @@ getFileHeader locals = do
      else do
        skip 4 -- skip past signature
        skip 2 -- version made by
-       versionNeededToExtract <- getWord16le
+       versionNeededToExtract <- getWord8
+       skip 1 -- upper byte indicates OS part of "version needed to extract"
        unless (versionNeededToExtract <= 20) $
          fail "This archive requires zip >= 2.0 to extract."
        skip 2 -- general purpose bit flag
